"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
var inversify_config_1 = require("../inversify.config");
var chai_1 = require("chai");
var path = require("path");
describe('SpawnAsync (no console out)', function () {
    var spawn;
    beforeEach(function (done) {
        spawn = inversify_config_1.default.get('Spawn');
        done();
    });
    afterEach(function (done) {
        spawn = null;
        done();
    });
    describe('spawnShellCommandAsync (force error)', function () {
        it('should report error', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            spawn.forceError = true;
            spawn.spawnShellCommandAsync([], null, function (err, result) {
                chai_1.expect(result).to.equal(null);
                chai_1.expect(err).to.not.equal(null);
                chai_1.expect(err.message).to.equal('force error: spawnShellCommandAsync');
            });
            done();
        });
    });
    describe('spawnShellCommandAsync (null command)', function () {
        it('should report error', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            spawn.spawnShellCommandAsync(null, null, function (err, result) {
                chai_1.expect(result).to.equal(null);
                chai_1.expect(err).to.not.equal(null);
                chai_1.expect(err.message).to.equal('Bad argument');
            });
            done();
        });
    });
    describe('spawnShellCommandAsync (empty array command)', function () {
        it('should report error', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            spawn.spawnShellCommandAsync([], null, function (err, result) {
                chai_1.expect(result).to.equal(null);
                chai_1.expect(err).to.not.equal(null);
                chai_1.expect(err.message).to.equal('Bad argument');
            });
            done();
        });
    });
});
describe('SpawnAsync (with console out)', function () {
    var spawn;
    var testScriptName = path.resolve(__dirname, 'test-00.js');
    var testErrorScriptName = path.resolve(__dirname, 'test-error-00.js');
    var cmd;
    beforeEach(function (done) {
        spawn = inversify_config_1.default.get('Spawn');
        cmd = ['/usr/bin/env', 'node', testScriptName];
        done();
    });
    describe('spawnShellCommandSync (invalid script,no options,no callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            cmd[2] = 'happyGoLucky';
            var childProcess = spawn.spawnShellCommandAsync(cmd);
            chai_1.expect(childProcess).to.not.equal(null);
            chai_1.expect(childProcess.spawnfile).to.equal('/usr/bin/env');
            childProcess.on('close', function (code) {
                chai_1.expect(code).to.not.equal(0);
                done();
            });
        });
    });
    describe('spawnShellCommandSync (invalid command,no options,no callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            var childProcess = spawn.spawnShellCommandAsync(['luv', 'muffins', 'forEveryone']);
            chai_1.expect(childProcess).to.not.equal(null);
            childProcess.on('error', function (err) {
                chai_1.expect(err.code).to.equal('ENOENT');
            });
            childProcess.on('close', function (code) {
                chai_1.expect(code).to.not.equal(0);
                done();
            });
        });
    });
    describe('spawnShellCommandSync (valid command,no options,no callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            var childProcess = spawn.spawnShellCommandAsync(cmd);
            chai_1.expect(childProcess).to.not.equal(null);
            chai_1.expect(childProcess.spawnfile).to.equal('/usr/bin/env');
            var result = '';
            childProcess.stdout.on('data', function (data) {
                result += data.toString();
            });
            childProcess.on('close', function (code) {
                chai_1.expect(code).to.equal(0);
                chai_1.expect(result).to.equal('test me: 0\ntest me: 1\ntest me: 2\n');
                done();
            });
        });
    });
    describe('spawnShellCommandSync (valid command,empty options,final callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            spawn.spawnShellCommandAsync(cmd, {}, function (err, result) {
                chai_1.expect(err).to.equal(null);
                chai_1.expect(result).to.equal('test me: 0\ntest me: 1\ntest me: 2\n');
                done();
            });
        });
    });
    describe('spawnShellCommandSync (invalid script,empty options,final callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            cmd[2] = 'happyGoLucky';
            spawn.spawnShellCommandAsync(cmd, {}, function (err, result) {
                chai_1.expect(err).to.not.equal(null);
                chai_1.expect(result).to.equal('');
                chai_1.expect(err.message).to.equal('spawn error: exit code 1');
                done();
            });
        });
    });
    describe('spawnShellCommandSync (invalid script,empty options,status callback,final callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            cmd[2] = 'happyGoLucky';
            spawn.spawnShellCommandAsync(cmd, {}, function () {
            }, function (err, result) {
                chai_1.expect(err).to.not.equal(null);
                chai_1.expect(result).to.equal('');
                chai_1.expect(err.message).to.equal('spawn error: exit code 1');
                done();
            });
        });
    });
    describe('spawnShellCommandSync (invalid command,empty options,final callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            spawn.spawnShellCommandAsync(['luv', 'muffins', 'forEveryone'], {}, function (err, result) {
                chai_1.expect(err).to.not.equal(null);
                chai_1.expect(result).to.equal(null);
                chai_1.expect(err.message).to.equal('spawn error: exit code ENOENT');
                done();
            });
        });
    });
    describe('spawnShellCommandSync (invalid command,empty options,status callback,final callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            spawn.spawnShellCommandAsync(['luv', 'muffins', 'forEveryone'], {}, function () {
            }, function (err, result) {
                chai_1.expect(err).to.not.equal(null);
                chai_1.expect(result).to.equal(null);
                chai_1.expect(err.message).to.equal('spawn error: exit code ENOENT');
                done();
            });
        });
    });
    describe('spawnShellCommandSync (valid command,empty options,status callback,final callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            var accumResult = '';
            spawn.spawnShellCommandAsync(cmd, {}, function (err, result) {
                chai_1.expect(err).to.equal(null);
                accumResult += result;
            }, function (err, result) {
                chai_1.expect(err).to.equal(null);
                chai_1.expect(result).to.equal(accumResult);
                chai_1.expect(result).to.equal('test me: 0\ntest me: 1\ntest me: 2\n');
                done();
            });
        });
    });
    describe('spawnShellCommandSync (valid command {non-zero exit code},empty options,status callback,final callback)', function () {
        it('should execute script and return', function (done) {
            chai_1.expect(spawn).to.not.equal(null);
            var accumResult = '';
            cmd = ['/usr/bin/env', 'node', testErrorScriptName];
            spawn.spawnShellCommandAsync(cmd, {}, function (err, result) {
                chai_1.expect(err).to.equal(null);
                accumResult += result;
            }, function (err, result) {
                chai_1.expect(err).to.not.equal(null);
                chai_1.expect(err.message).to.equal('spawn error: exit code 3');
                chai_1.expect(result).to.equal(accumResult);
                chai_1.expect(result).to.equal('test me: 0\ntest me: 1\n');
                done();
            });
        });
    });
});
//# sourceMappingURL=spawn-async.test.js.map